spannertools.report_spanner_format_contributions
================================================

.. autofunction:: abjad.tools.spannertools.report_spanner_format_contributions.report_spanner_format_contributions
   :noindex:
